diff OrthancServer/Internals/CommandDispatcher.cpp @ 2068:879f3be759ef

renames to make code clearer
author Sebastien Jodogne <s.jodogne@gmail.com>
date Wed, 13 Jul 2016 16:10:25 +0200
parents b1291df2f780
children ddc75c6c712d
line wrap: on
line diff
--- a/OrthancServer/Internals/CommandDispatcher.cpp	Wed Jul 13 15:55:50 2016 +0200
+++ b/OrthancServer/Internals/CommandDispatcher.cpp	Wed Jul 13 16:10:25 2016 +0200
@@ -727,16 +727,16 @@
       else if (cond == DIMSE_NODATAAVAILABLE)
       {
         // Timeout due to DIMSE_NONBLOCKING
-        if (clientTimeout_ != 0 && 
-            elapsedTimeSinceLastCommand_ >= clientTimeout_)
+        if (associationTimeout_ != 0 && 
+            elapsedTimeSinceLastCommand_ >= associationTimeout_)
         {
           // This timeout is actually a client timeout
           finished = true;
         }
       }
       else if (cond == EC_Normal)
       {
         // Reset the client timeout counter
         elapsedTimeSinceLastCommand_ = 0;
 
         // Convert the type of request to Orthanc's internal type
@@ -727,16 +727,16 @@
         {
-          // This timeout is actually a client timeout
+          // This timeout is actually a association timeout
           finished = true;
         }
@@ -727,16 +727,16 @@
       else if (cond == EC_Normal)
       {
-        // Reset the client timeout counter
+        // Reset the association timeout counter
         elapsedTimeSinceLastCommand_ = 0;
 